==> chromium-92.0.4515.92.tar.xz: chromium-92.0.4515.92/chrome/browser/ui/autofill/save_update_address_profile_bubble_controller_impl.h <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_AUTOFILL_SAVE_UPDATE_ADDRESS_PROFILE_BUBBLE_CONTROLLER_IMPL_H_
#define CHROME_BROWSER_UI_AUTOFILL_SAVE_UPDATE_ADDRESS_PROFILE_BUBBLE_CONTROLLER_IMPL_H_

#include <string>

#include "chrome/browser/ui/autofill/autofill_bubble_controller_base.h"
#include "chrome/browser/ui/autofill/save_address_profile_icon_controller.h"
#include "chrome/browser/ui/autofill/save_update_address_profile_bubble_controller.h"
#include "components/autofill/core/browser/autofill_client.h"
#include "components/autofill/core/browser/data_model/autofill_profile.h"
#include "content/public/browser/web_contents_user_data.h"

namespace autofill {

class AutofillBubbleBase;

// The controller functionality for SaveAddressProfileView.
class SaveUpdateAddressProfileBubbleControllerImpl
    : public AutofillBubbleControllerBase,
      public SaveUpdateAddressProfileBubbleController,
      public SaveAddressProfileIconController,
      public content::WebContentsUserData<
          SaveUpdateAddressProfileBubbleControllerImpl> {
 public:
  SaveUpdateAddressProfileBubbleControllerImpl(
      const SaveUpdateAddressProfileBubbleControllerImpl&) = delete;
  SaveUpdateAddressProfileBubbleControllerImpl& operator=(
      const SaveUpdateAddressProfileBubbleControllerImpl&) = delete;
  ~SaveUpdateAddressProfileBubbleControllerImpl() override;

  // Sets up the controller and offers to save the `profile`. If
  // `original_profile` is not nullptr, it will be updated of the user accepts
  // the offer. `address_profile_save_prompt_callback` will be invoked once the
  // user makes a decision with respect to the offer-to-save prompt.
  // `options` carries extra configuration for opening the prompt.
  void OfferSave(const AutofillProfile& profile,
                 const AutofillProfile* original_profile,
                 AutofillClient::SaveAddressProfilePromptOptions options,
                 AutofillClient::AddressProfileSavePromptCallback
                     address_profile_save_prompt_callback);

  // SaveUpdateAddressProfileBubbleController:
  std::u16string GetWindowTitle() const override;
  const AutofillProfile& GetProfileToSave() const override;
  const AutofillProfile* GetOriginalProfile() const override;
  void OnUserDecision(
      AutofillClient::SaveAddressProfileOfferUserDecision decision) override;
  void OnEditButtonClicked() override;
  void OnBubbleClosed() override;

  // SaveAddressProfileIconController:
  void OnPageActionIconClicked() override;
  bool IsBubbleActive() const override;
  std::u16string GetPageActionIconTootip() const override;
  AutofillBubbleBase* GetBubbleView() const override;
  bool IsSaveBubble() const override;

 protected:
  // AutofillBubbleControllerBase:
  void WebContentsDestroyed() override;
  PageActionIconType GetPageActionIconType() override;
  void DoShowBubble() override;

 private:
  explicit SaveUpdateAddressProfileBubbleControllerImpl(
      content::WebContents* web_contents);
  friend class content::WebContentsUserData<
      SaveUpdateAddressProfileBubbleControllerImpl>;

  // Callback to run once the user makes a decision with respect to the saving
  // the address profile.
  AutofillClient::AddressProfileSavePromptCallback
      address_profile_save_prompt_callback_;

  // Contains the details of the address profile that will be saved if the user
  // accepts.
  AutofillProfile address_profile_;

  // Contains the details of the address profile that will be updated if the
  // user accepts the prompt.
  absl::optional<AutofillProfile> original_profile_;

  // Whether the bubble is going to be shown upon user gesture (e.g. click on
  // the page action icon) or automatically (e.g. upon detection of an address
  // during form submission).
  bool shown_by_user_gesture_ = false;

  WEB_CONTENTS_USER_DATA_KEY_DECL();
};

}  // namespace autofill

#endif  // CHROME_BROWSER_UI_AUTOFILL_SAVE_UPDATE_ADDRESS_PROFILE_BUBBLE_CONTROLLER_IMPL_H_

==> chromium-93.0.4549.3.tar.xz: chromium-93.0.4549.3/chrome/browser/ui/autofill/save_update_address_profile_bubble_controller_impl.h <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_AUTOFILL_SAVE_UPDATE_ADDRESS_PROFILE_BUBBLE_CONTROLLER_IMPL_H_
#define CHROME_BROWSER_UI_AUTOFILL_SAVE_UPDATE_ADDRESS_PROFILE_BUBBLE_CONTROLLER_IMPL_H_

#include <string>

#include "chrome/browser/ui/autofill/autofill_bubble_controller_base.h"
#include "chrome/browser/ui/autofill/save_address_profile_icon_controller.h"
#include "chrome/browser/ui/autofill/save_update_address_profile_bubble_controller.h"
#include "components/autofill/core/browser/autofill_client.h"
#include "components/autofill/core/browser/data_model/autofill_profile.h"
#include "content/public/browser/web_contents_user_data.h"

namespace autofill {

class AutofillBubbleBase;

// The controller functionality for SaveAddressProfileView.
class SaveUpdateAddressProfileBubbleControllerImpl
    : public AutofillBubbleControllerBase,
      public SaveUpdateAddressProfileBubbleController,
      public SaveAddressProfileIconController,
      public content::WebContentsUserData<
          SaveUpdateAddressProfileBubbleControllerImpl> {
 public:
  SaveUpdateAddressProfileBubbleControllerImpl(
      const SaveUpdateAddressProfileBubbleControllerImpl&) = delete;
  SaveUpdateAddressProfileBubbleControllerImpl& operator=(
      const SaveUpdateAddressProfileBubbleControllerImpl&) = delete;
  ~SaveUpdateAddressProfileBubbleControllerImpl() override;

  // Sets up the controller and offers to save the `profile`. If
  // `original_profile` is not nullptr, it will be updated of the user accepts
  // the offer. `address_profile_save_prompt_callback` will be invoked once the
  // user makes a decision with respect to the offer-to-save prompt.
  // `options` carries extra configuration for opening the prompt.
  void OfferSave(const AutofillProfile& profile,
                 const AutofillProfile* original_profile,
                 AutofillClient::SaveAddressProfilePromptOptions options,
                 AutofillClient::AddressProfileSavePromptCallback
                     address_profile_save_prompt_callback);

  // SaveUpdateAddressProfileBubbleController:
  std::u16string GetWindowTitle() const override;
  const AutofillProfile& GetProfileToSave() const override;
  const AutofillProfile* GetOriginalProfile() const override;
  void OnUserDecision(
      AutofillClient::SaveAddressProfileOfferUserDecision decision) override;
  void OnEditButtonClicked() override;
  void OnBubbleClosed() override;

  // SaveAddressProfileIconController:
  void OnPageActionIconClicked() override;
  bool IsBubbleActive() const override;
  std::u16string GetPageActionIconTootip() const override;
  AutofillBubbleBase* GetSaveBubbleView() const override;

 protected:
  // AutofillBubbleControllerBase:
  void WebContentsDestroyed() override;
  PageActionIconType GetPageActionIconType() override;
  void DoShowBubble() override;

 private:
  explicit SaveUpdateAddressProfileBubbleControllerImpl(
      content::WebContents* web_contents);
  friend class content::WebContentsUserData<
      SaveUpdateAddressProfileBubbleControllerImpl>;

  // Callback to run once the user makes a decision with respect to the saving
  // the address profile.
  AutofillClient::AddressProfileSavePromptCallback
      address_profile_save_prompt_callback_;

  // Contains the details of the address profile that will be saved if the user
  // accepts.
  AutofillProfile address_profile_;

  // Contains the details of the address profile that will be updated if the
  // user accepts the prompt.
  absl::optional<AutofillProfile> original_profile_;

  // Whether the bubble is going to be shown upon user gesture (e.g. click on
  // the page action icon) or automatically (e.g. upon detection of an address
  // during form submission).
  bool shown_by_user_gesture_ = false;

  WEB_CONTENTS_USER_DATA_KEY_DECL();
};

}  // namespace autofill

#endif  // CHROME_BROWSER_UI_AUTOFILL_SAVE_UPDATE_ADDRESS_PROFILE_BUBBLE_CONTROLLER_IMPL_H_
